@@ -10,16 +10,14 @@ use Moo;
 use strict;
 use warnings;
 use autodie;
-use version;
 use Data::Dumper qw/Dumper/;
 use English qw/ -no_match_vars /;
 use Type::Tiny;
 use Types::Standard -types;
 use File::ShareDir qw/dist_dir/;
 use YAML qw/LoadFile/;
-use File::TypeCategories::Git;
 
-our $VERSION = version->new('0.8.2');
+our $VERSION = 0.04;
 our %warned_once;
 
 has ignore => (
@@ -27,10 +25,6 @@ has ignore => (
     isa     => ArrayRef[Str],
     default => sub{[qw{ ignore }]},
 );
-has git => (
-    is  => 'rw',
-    isa => Bool,
-);
 has include => (
     is  => 'rw',
     isa => ArrayRef[Str],
@@ -50,8 +44,9 @@ has exclude_type => (
     default => sub{[]},
 );
 has symlinks => (
-    is  => 'rw',
-    isa => Bool,
+    is      => 'rw',
+    isa     => Bool,
+    default => 0,
 );
 has type_suffixes => (
     is      => 'rw',
@@ -65,13 +60,12 @@ sub BUILD {
     if (!$ENV{HOME}) {
         $ENV{HOME} = $ENV{USERPROFILE};
     }
-    my $dir = eval { dist_dir('File-TypeCategories'); };
+    my $dir = dist_dir('File-TypeCategories');
     my $config_name = '.type_categories.yml';
 
     # import each config file the each subsiquent config overwrites the
     # previous more general config.
     for my $config_dir ($dir, $ENV{HOME}, '.') {
-        next if ! $config_dir || !-d $config_dir;
         my $config_file = "$config_dir/$config_name";
         next if !-f $config_file;
 
@@ -79,22 +73,13 @@ sub BUILD {
 
         # import each type
         for my $file_type ( keys %{ $conf } ) {
-            if ( ! $self->type_suffixes->{$file_type} ) {
-                $self->type_suffixes->{$file_type} ||= {
-                    definite    => [],
-                    possible    => [],
-                    other_types => [],
-                    none        => 0,
-                    bang        => '',
-                    Config      => $config_file,
-                };
-            }
-            else {
-                if ( ! ref $self->type_suffixes->{$file_type}{Config} ) {
-                    $self->type_suffixes->{$file_type}{Config} = [ $self->type_suffixes->{$file_type}{Config} ];
-                }
-                push @{$self->type_suffixes->{$file_type}{Config}}, $config_file;
-            }
+            $self->type_suffixes->{$file_type} ||= {
+                definite    => [],
+                possible    => [],
+                other_types => [],
+                none        => 0,
+                bang        => '',
+            };
 
             # add each of the settings found
             for my $setting ( keys %{ $conf->{$file_type} } ) {
@@ -117,12 +102,6 @@ sub BUILD {
         }
     }
 
-    if ($self->git) {
-        my $git_ignore = File::TypeCategories::Git->new();
-        $self->type_suffixes->{git} = $git_ignore->ignores();
-        push @{ $self->type_suffixes->{ignore} }, 'git';
-    }
-
     return;
 }
 
@@ -213,40 +192,6 @@ sub types_match {
     return 0;
 }
 
-sub show_types {
-    my ($self, $type) = @_;
-    my $out = '';
-
-    if ( $type ) {
-        my $details = $self->type_suffixes->{$type};
-        $out .= "$type:\n";
-        if ($details) {
-            for my $key (sort keys %{ $details }) {
-                next if $details->{$key} eq '' || (ref $details->{$key} && $#{$details->{$key}} == -1);
-                my $value = $details->{$key};
-                my $gap = ' ';
-                if (ref $value) {
-                    my $min_length = length join ', ', @$value;
-                    my $seperator = $min_length > 78 ? "\n    " : ', ';
-                    $gap = $min_length > 78 ? "\n    " : ' ';
-                    $value = join $seperator, map {$min_length > 78 ? $_ : "'$_'"} @$value;
-                }
-                $out .= "  $key:$gap$value\n";
-            }
-        }
-        else {
-            $out .= "  Type not defined\n";
-        }
-    }
-    else {
-        $out .= "Types:\n  ";
-        $out .= join "\n  ", sort keys %{ $self->type_suffixes };
-        $out .= "\n";
-    }
-
-    return $out;
-}
-
 1;
 
 __END__
@@ -257,7 +202,7 @@ File::TypeCategories - Determine if files match a specific type
 
 =head1 VERSION
 
-This documentation refers to File::TypeCategories version 0.8.2
+This documentation refers to File::TypeCategories version 0.04
 
 =head1 SYNOPSIS
 
